@@ -58,7 +58,7 @@ class AbstractNnTrainer(object):
         self,
         neural_network: torch.nn.Module, 
         optimizer_fn: Any = torch.optim.Adam,
-        optimizer_params: Dict = dict(lr=2e-2),
+        optimizer_params: Dict = dict(lr=0.0001),
         scheduler_fn: Any = None,
         scheduler_params: Dict = field(default_factory=dict),
         dtype: Any = torch.float32,
