@@ -29,7 +29,7 @@ class BasicNnTrainer(AbstractNnTrainer):
         verbose: bool = False,
         patience: int = 0,
         optimizer_fn: Any = torch.optim.Adam,
-        optimizer_params: Dict = dict(lr=2e-2),# field(default_factory=lambda: ),
+        optimizer_params: Dict = dict(lr=0.0001),# field(default_factory=lambda: ),
         scheduler_fn: Any = None,
         scheduler_params: Dict = field(default_factory=dict),
         dtype: Any = torch.float32,
@@ -69,18 +69,18 @@ class BasicNnTrainer(AbstractNnTrainer):
 
         """
         super().__init__(
-            neural_network,
-            optimizer_fn,
-            optimizer_params,
-            scheduler_fn,
-            scheduler_params,
-            dtype,
-            verbose,
-            patience,
-            max_epoch_count,
-            batch_size,
-            output_dir,
-            logger
+            neural_network=neural_network,
+            optimizer_fn=optimizer_fn,
+            optimizer_params=optimizer_params,
+            scheduler_fn=scheduler_fn,
+            scheduler_params=scheduler_params,
+            dtype=dtype,
+            verbose=verbose,
+            patience=patience,
+            max_epoch_count=max_epoch_count,
+            batch_size=batch_size,
+            output_dir=output_dir,
+            logger=logger
         )
 
     def train(
