@@ -36,9 +36,9 @@ class WassersteinGanNnTrainer(AbstractNnTrainer):
         generator_neural_network: torch.nn.Module, 
         discriminator_neural_network: torch.nn.Module, 
         generator_optimizer_fn: Any = torch.optim.Adam,
-        generator_optimizer_params: Dict = dict(lr=0.0002),
+        generator_optimizer_params: Dict = dict(lr=0.0001),
         discriminator_optimizer_fn: Any = torch.optim.Adam,
-        discriminator_optimizer_params: Dict = dict(lr=0.0002),
+        discriminator_optimizer_params: Dict = dict(lr=0.0001),
         scheduler_fn: Any = None,
         scheduler_params: Dict = field(default_factory=dict),
         dtype: Any = torch.float32,
@@ -71,18 +71,19 @@ class WassersteinGanNnTrainer(AbstractNnTrainer):
             logger (Logger, optional): Defaults to None.
         """
         super().__init__(
-            generator_neural_network, 
-            generator_optimizer_fn,
-            generator_optimizer_params,
-            scheduler_fn,
-            scheduler_params,
-            dtype,
-            verbose,
-            patience,
-            max_epoch_count,
-            batch_size,
-            output_dir,
-            logger)
+            neural_network=generator_neural_network, 
+            optimizer_fn=generator_optimizer_fn,
+            optimizer_params=generator_optimizer_params,
+            scheduler_fn=scheduler_fn,
+            scheduler_params=scheduler_params,
+            dtype=dtype,
+            verbose=verbose,
+            patience=patience,
+            max_epoch_count=max_epoch_count,
+            batch_size=batch_size,
+            output_dir=output_dir,
+            logger=logger
+            )
         self._critic_iterations = critic_iterations
         self._net_d = discriminator_neural_network.type(dtype)
         self._net_d.to(self._device)
